pub struct Lazy<C: LazyComponent> { /* private fields */ }Expand description
Wrapper for a lazily fetched component
This component suspends as long as the underlying component is still being fetched, then behaves as the underlying component itself.